@@ -22,6 +22,11 @@ CONFIG={  'filename':'~/.config/test/cfg.json',
           # ------------------ ASTRO speed compensation
           'x':0,
           'y':0 ,
+          'rotate180':False,
+          # ------------------------
+          'expo':'auto',
+          'gamma':'def',
+          'gain':'def',
           #-----------------------
 #          'camera_on':False,   # quewstionable...
           'interpolation':'None',
