@@ -19,6 +19,7 @@ from  flashcam.stream_enhancer import Stream_Enhancer
 
 
 from flashcam import v4lc
+from flashcam.v4lc import set_gem
 
 from flashcam.mmapwr import mmread_n_clear
 
@@ -63,6 +64,7 @@ class Camera(BaseCamera):
             #cap = cv2.VideoCapture(vidnum)
             #   70% stucks even with timeout
             pixelformat = "MJPG"
+            pixelformat = "YUYV"
             w,h =  int(res.split("x")[0]), int(res.split("x")[1])
             fourcc = cv2.VideoWriter_fourcc(*pixelformat)
             cap.set(cv2.CAP_PROP_FOURCC, fourcc)
@@ -98,8 +100,9 @@ class Camera(BaseCamera):
         timelaps     = int(config.CONFIG['timelaps'])
         histogram    = config.CONFIG['histogram']
         res          = config.CONFIG['resolution']
-        speedx          = float(config.CONFIG['x'])
-        speedy          = float(config.CONFIG['y'])
+        speedx       = float(config.CONFIG['x'])
+        speedy       = float(config.CONFIG['y'])
+        rotate180    = config.CONFIG['rotate180']
 
         # ------------------    to evaluate commands from web.py
         substract_background = False
@@ -118,7 +121,8 @@ class Camera(BaseCamera):
         expo_multiply =False
         expo_setdef =False
 
-        rotate180 = False
+        # rotate180 = False # i define earlier from CONFIG
+
         fixed_image = None # just camera.
 
         camera = Camera(  )
@@ -128,6 +132,12 @@ class Camera(BaseCamera):
         capa = cc.get_capbilities()
 
 
+        # I CALL SET_GAM from
+        set_gem(cc, config.CONFIG['gain'],
+                config.CONFIG['expo'],
+                config.CONFIG['gamma'])
+
+
         # very stupid camera    ZC0303 Webcam
         if "exposure" in capa:
             exposure = cc.get_exposure()
