@@ -261,6 +261,104 @@ class V4L2_CTL():
 
 # print("v... unit 'unitname' loaded, version:",__version__)
 
+
+
+
+
+
+def set_gem(cc, gain, expo, mmaga):
+    capa = cc.get_capbilities()
+
+    if expo == "auto":
+        if "exposure_absolute" in capa:
+            print("D... AUTO EXPOSURE ON")
+            cc.setdef_exposure_auto() # doesnt do default 3
+            print("ex def",cc.get_exposure_auto())
+            cc.setdef_exposure_auto()  # i thik he knows what is auto
+    elif expo !=-1:
+        if "exposure_absolute" in capa:
+            if "exposure_auto" in capa:
+                print("D... AUTO EXPOSURE OFF")
+                cc.setdef_exposure_auto() # doesnt do default 3
+                print("ex def",cc.get_exposure_auto())
+                cc.set_exposure_auto(1)  # I just a guess, 1 may be manual, 3
+
+
+                ex = cc.get_exposure_absolute()
+                mine = cc.getmin_exposure_absolute()
+                maxe = cc.getmax_exposure_absolute()
+                print(f"i... current exposure {ex}   range {mine}, {maxe}")
+
+                ex = int( expo * (maxe-mine)+mine)
+                print("i... new = ",ex)
+                if ex>maxe: ex=maxe
+                if ex<mine: ex=mine
+
+                cc.set_exposure_absolute(ex)
+        # very stupid wabcam
+        elif "exposure" in capa:
+            ex = cc.get_exposure()
+            mine = cc.getmin_exposure()
+            maxe = cc.getmax_exposure()
+            print(f"i... current exposure {ex}   range {mine}, {maxe}")
+
+            ex = int( expo * (maxe-mine)+mine)
+            print("i... new = ",ex)
+            if ex>maxe: ex=maxe
+            if ex<mine: ex=mine
+
+            cc.set_exposure(ex)
+        else:
+            print("X... exposure_absolute NOR exposure not in capacities")
+
+    if gain == "def":
+        if "gain" in capa:
+            cc.setdef_gain()
+    elif gain !=-1:
+        if "gain" in capa:
+            ga = cc.get_gain()
+            ming = cc.getmin_gain()
+            maxg = cc.getmax_gain()
+            print(f"i... current gain {ga}   range {ming}, {maxg}")
+
+            ga = int( gain * (maxg-ming)+ming)
+            print("i... new = ",ga)
+            if ga>maxg: ga=maxg
+            if ga<ming: ga=ming
+
+            cc.set_gain(ga)
+        else:
+            print("X... gain noit in capacities")
+
+
+    if mmaga == "def":
+        if "gamma" in capa:
+            cc.setdef_gamma()
+    elif mmaga !=-1:
+        if "gamma" in capa:
+            ga = cc.get_gamma()
+            ming = cc.getmin_gamma()
+            maxg = cc.getmax_gamma()
+            print(f"i... current gamma {ga}   range {ming}, {maxg}")
+
+            ga = int( mmaga * (maxg-ming)+ming)
+            print("i... new = ",ga)
+            if ga>maxg: ga=maxg
+            if ga<ming: ga=ming
+
+            cc.set_gamma(ga)
+        else:
+            print("X... gamma not in capacities")
+
+    #------------------------------------------end of function--- SET_GEM
+
+
+
+
+
+
+
+
 def func(debug = False):
 
     print("D... in unit unitname function func DEBUG may be filtered")
